@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2004-2021 Univention GmbH
+# Copyright 2004-2022 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -350,6 +350,8 @@ class object(univention.admin.handlers.simpleLdap):
 							cache_uniqueMember.set(i, {'type': 'host'})
 						elif set(result) & {b'person', b'inetOrgPerson', b'organizationalPerson'}:
 							self['users'].append(i)
+						elif b'univentionUserTemplate' in result:
+							continue
 						else:
 							raise RuntimeError('%s not detected: %r' % (i, result))
 
