@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2004-2021 Univention GmbH
+# Copyright 2004-2022 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -48,6 +48,7 @@ import pytz
 import six
 from ldap.filter import filter_format
 import tzlocal
+import passlib.hash
 from M2Crypto import X509
 
 import univention.admin
@@ -734,6 +735,14 @@ property_descriptions = {
 		multivalue=True,
 		copyable=True,
 	),
+	'serviceSpecificPassword': univention.admin.property(
+		short_description=_('Service Specific Password'),
+		long_description=_('Virtual attribute to set different Service Specific Passwords via UDM'),
+		syntax=univention.admin.syntax.string,
+		dontsearch=True,
+		show_in_lists=False,
+		cli_enabled=False,
+	),
 }
 
 default_property_descriptions = copy.deepcopy(property_descriptions)  # for later reset of descriptions
@@ -1074,6 +1083,18 @@ def unmapSambaKickoffTimeToUserexpiry(oldattr):
 		return time.strftime("%Y-%m-%d", time.gmtime(long(oldattr['sambaKickoffTime'][0]) + (3600 * 24)))
 
 
+def _mapUserExpiryToShadowExpire(userexpiry):
+	return u"%d" % long(time.mktime(time.strptime(userexpiry, "%Y-%m-%d")) / 3600 / 24 + 1)
+
+
+def _mapUserExpiryToKrb5ValidEnd(userexpiry):
+	return u"%s%s%s000000Z" % (userexpiry[0:4], userexpiry[5:7], userexpiry[8:10])
+
+
+def _mapUserExpiryToSambaKickoffTime(userexpiry):
+	return u"%d" % long(time.mktime(time.strptime(userexpiry, "%Y-%m-%d")))
+
+
 def unmapPasswordExpiry(oldattr):
 	if oldattr.get('shadowLastChange') and oldattr.get('shadowMax'):
 		shadow_max = int(oldattr['shadowMax'][0])
@@ -1772,10 +1793,11 @@ class object(univention.admin.handlers.simpleLdap):
 		ml = self._modlist_krb5_valid_end(ml)
 		ml = self._modlist_shadow_expire(ml)
 		ml = self._modlist_mail_forward(ml)
-		ml = self._modlist_univention_person(ml)
 		ml = self._modlist_home_share(ml)
 		ml = self._modlist_samba_sid(ml)
 		ml = self._modlist_primary_group(ml)
+		ml = self._modlist_service_specific_password(ml)
+		ml = self._modlist_univention_person(ml)
 
 		return ml
 
@@ -2022,7 +2044,7 @@ class object(univention.admin.handlers.simpleLdap):
 		if self.hasChanged('userexpiry'):
 			sambaKickoffTime = b''
 			if self['userexpiry']:
-				sambaKickoffTime = b"%d" % long(time.mktime(time.strptime(self['userexpiry'], "%Y-%m-%d")))
+				sambaKickoffTime = _mapUserExpiryToSambaKickoffTime(self['userexpiry']).encode("ASCII")
 				ud.debug(ud.ADMIN, ud.INFO, 'sambaKickoffTime: %s' % sambaKickoffTime)
 			old_sambaKickoffTime = self.oldattr.get('sambaKickoffTime', [b''])[0]
 			if old_sambaKickoffTime != sambaKickoffTime:
@@ -2033,7 +2055,7 @@ class object(univention.admin.handlers.simpleLdap):
 		if self.hasChanged('userexpiry'):
 			krb5ValidEnd = u''
 			if self['userexpiry']:
-				krb5ValidEnd = u"%s%s%s000000Z" % (self['userexpiry'][0:4], self['userexpiry'][5:7], self['userexpiry'][8:10])
+				krb5ValidEnd = _mapUserExpiryToKrb5ValidEnd(self['userexpiry'])
 				ud.debug(ud.ADMIN, ud.INFO, 'krb5ValidEnd: %s' % krb5ValidEnd)
 			krb5ValidEnd = krb5ValidEnd.encode('ASCII')
 			old_krb5ValidEnd = self.oldattr.get('krb5ValidEnd', [b''])[0]
@@ -2049,7 +2071,7 @@ class object(univention.admin.handlers.simpleLdap):
 			if self['disabled'] == '1' and self.hasChanged('disabled') and not self.hasChanged('userexpiry'):
 				shadowExpire = u'1'
 			elif self['userexpiry']:
-				shadowExpire = u"%d" % long(time.mktime(time.strptime(self['userexpiry'], "%Y-%m-%d")) / 3600 / 24 + 1)
+				shadowExpire = _mapUserExpiryToShadowExpire(self['userexpiry'])
 			elif self['disabled'] == '1':
 				shadowExpire = u'1'
 			else:
@@ -2094,7 +2116,7 @@ class object(univention.admin.handlers.simpleLdap):
 
 	def _modlist_univention_person(self, ml):
 		# make sure that univentionPerson is set as objectClass when needed
-		if any(self.hasChanged(ikey) and self[ikey] for ikey in ('umcProperty', 'birthday')) and b'univentionPerson' not in self.oldattr.get('objectClass', []):
+		if any(self.hasChanged(ikey) and self[ikey] for ikey in ('umcProperty', 'birthday', 'serviceSpecificPassword')) and b'univentionPerson' not in self.oldattr.get('objectClass', []):
 			ml.append(('objectClass', b'', b'univentionPerson'))  # TODO: check if exists already
 		return ml
 
@@ -2173,6 +2195,18 @@ class object(univention.admin.handlers.simpleLdap):
 			ml.append(('sambaAcctFlags', old_flags, new_flags))
 		return ml
 
+	def _modlist_service_specific_password(self, ml):
+		new_password = self.info.get('serviceSpecificPassword', None)
+		if new_password:
+			service = new_password.get('service', None)
+			password = new_password.get('password', None)
+			if service != 'radius':
+				raise univention.admin.uexceptions.valueError(_('Service does not support service specific passwords'), property='serviceSpecificPassword')
+			if service:
+				nt = passlib.hash.nthash.hash(password).upper().encode('ASCII')
+				ml.append(('univentionRadiusPassword', self.oldattr.get('univentionRadiusPassword', [b'']), [nt]))
+		return ml
+
 	def _ldap_post_remove(self):
 		self.alloc.append(('sid', self.oldattr['sambaSID'][0].decode('ASCII')))
 		self.alloc.append(('uid', self.oldattr['uid'][0].decode('UTF-8')))
@@ -2329,6 +2363,21 @@ class object(univention.admin.handlers.simpleLdap):
 				filter.transform_to_conjunction(univention.admin.filter.parse(u'(&(shadowExpire=1)(krb5KDCFlags=254))'))
 			elif filter.value == u'*':
 				filter.variable = u'uid'
+		elif filter.variable == 'userexpiry':
+			try:
+				userexpiry = property_descriptions['userexpiry'].syntax.parse(filter.value)
+			except univention.admin.uexceptions.valueError:
+				# allow to search for userexpiry=*
+				# TODO: should we allow to search for e.g. userexpiry=2021-* ?
+				userexpiry_filter = filter_format(u'(|(shadowExpire=%s)(krb5ValidEnd=%s)(sambaKickoffTime=%s))', [filter.value or '*', filter.value or '*', filter.value or '*'])
+				userexpiry_filter = userexpiry_filter.replace(filter_format('%s', ['*']), '*')
+			else:
+				userexpiry_filter = filter_format(u'(|(shadowExpire=%s)(krb5ValidEnd=%s)(sambaKickoffTime=%s))', [
+					_mapUserExpiryToShadowExpire(userexpiry),
+					_mapUserExpiryToKrb5ValidEnd(userexpiry),
+					_mapUserExpiryToSambaKickoffTime(userexpiry),
+				])
+			filter.transform_to_conjunction(univention.admin.filter.parse(userexpiry_filter))
 		elif filter.variable == u'locked':
 			if filter.value == u'1':
 				filter.transform_to_conjunction(univention.admin.filter.parse(u'(|(krb5KDCFlags:1.2.840.113556.1.4.803:=131072)(sambaAcctFlags=[UL       ])(sambaAcctFlags=[ULD       ]))'))
