@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2004-2021 Univention GmbH
+# Copyright 2004-2022 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -510,7 +510,7 @@ class mapping(object):
 		"""
 		return self._unmap.get(unmap_name, [''])[0]
 
-	def mapValue(self, map_name, value):
+	def mapValue(self, map_name, value, encoding_errors=None):
 		"""
 		Map |UDM| property value to |LDAP| attribute value.
 
@@ -543,6 +543,7 @@ class mapping(object):
 			return b''
 
 		encoding, strictness = self._map_encoding.get(map_name, ('UTF-8', 'strict'))
+		strictness = encoding_errors or strictness
 		if not map_value:
 			map_value = MapToBytes
 		kwargs = {}
@@ -555,13 +556,15 @@ class mapping(object):
 			raise univention.admin.uexceptions.valueInvalidSyntax(_('Invalid encoding for %s') % (map_name,))
 		return value
 
-	def mapValueDecoded(self, map_name, value):
-		value = self.mapValue(map_name, value)
+	def mapValueDecoded(self, map_name, value, encoding_errors=None):
+		encoding, errors = self.getEncoding(map_name)
+		errors = encoding_errors or errors
+		value = self.mapValue(map_name, value, encoding_errors=errors)
 		if isinstance(value, (list, tuple)):
 			ud.debug(ud.ADMIN, ud.WARN, 'mapValueDecoded returns a list for %s. This is probably not wanted?' % map_name)
-			value = [val.decode(*self.getEncoding(map_name)) for val in value]
+			value = [val.decode(encoding, errors) for val in value]
 		else:
-			value = value.decode(*self.getEncoding(map_name))
+			value = value.decode(encoding, errors)
 		return value
 
 	def unmapValue(self, unmap_name, value):
@@ -767,7 +770,7 @@ def mapRewrite(filter, mapping):
 		if not mapping.shouldMap(key):
 			return
 		k = mapping.mapName(key)
-		v = mapping.mapValueDecoded(key, filter.value)
+		v = mapping.mapValueDecoded(key, filter.value, encoding_errors='ignore')
 	except KeyError:
 		return
 	if k:
